=========================================
``psyclone.tests.psyir.backend.sir_test``
=========================================

.. automodule:: psyclone.tests.psyir.backend.sir_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.sir_test
